pub unsafe extern "C" fn b3Body_ApplyForce(
bodyId: b3BodyId,
force: b3Vec3,
point: b3Pos,
wake: bool,
)Expand description
Apply a force at a world point. If the force is not applied at the center of mass, it will generate a torque and affect the angular velocity. This optionally wakes up the body. The force is ignored if the body is not awake. @param bodyId The body id @param force The world force vector, usually in newtons (N) @param point The world position of the point of application @param wake Option to wake up the body