b3Body_ComputeAABB

Function b3Body_ComputeAABB 

pub unsafe extern "C" fn b3Body_ComputeAABB(
    bodyId: b3BodyId,
) -> b3AABB
Get the current world AABB that contains all the attached shapes. Note that this may not encompass the body origin. If there are no shapes attached then the returned AABB is empty and centered on the body origin.