b3Body_SetAwake

Function b3Body_SetAwake 

pub unsafe extern "C" fn b3Body_SetAwake(
    bodyId: b3BodyId,
    awake: bool,
)
Wake a body from sleep. This wakes the entire island the body is touching. @warning Putting a body to sleep will put the entire island of bodies touching this body to sleep, which can be expensive and possibly unintuitive.