b3Body_SetTargetTransform

Function b3Body_SetTargetTransform 

pub unsafe extern "C" fn b3Body_SetTargetTransform(
    bodyId: b3BodyId,
    target: b3WorldTransform,
    timeStep: f32,
    wake: bool,
)
Set the velocity to reach the given transform after a given time step. The result will be close but maybe not exact. This is meant for kinematic bodies. The target is not applied if the velocity would be below the sleep threshold. This will optionally wake the body if asleep, but only if the movement is significant.