b3Body_SetTransform

Function b3Body_SetTransform 

pub unsafe extern "C" fn b3Body_SetTransform(
    bodyId: b3BodyId,
    position: b3Pos,
    rotation: b3Quat,
)
Set the world transform of a body. This acts as a teleport and is fairly expensive. @note Generally you should create a body with the intended transform. @see b3BodyDef::position and b3BodyDef::rotation