pub unsafe extern "C" fn b3Body_SetType(
bodyId: b3BodyId,
type_: b3BodyType,
)Expand description
Change the body type. This is an expensive operation. This automatically updates the mass properties regardless of the automatic mass setting.
pub unsafe extern "C" fn b3Body_SetType(
bodyId: b3BodyId,
type_: b3BodyType,
)Change the body type. This is an expensive operation. This automatically updates the mass properties regardless of the automatic mass setting.