pub unsafe extern "C" fn b3Contact_GetData(
contactId: b3ContactId,
) -> b3ContactDataExpand description
Get the manifolds for a contact. The manifold may have no points if the contact is not touching.
pub unsafe extern "C" fn b3Contact_GetData(
contactId: b3ContactId,
) -> b3ContactDataGet the manifolds for a contact. The manifold may have no points if the contact is not touching.