b3ConvertCompoundToBytes

Function b3ConvertCompoundToBytes 

pub unsafe extern "C" fn b3ConvertCompoundToBytes(
    compound: *mut b3CompoundData,
) -> *mut u8
If bytes is null then this returns the number of required bytes. This clones all the data into the bytes buffer. This is expected to run offline or asynchronously. This mutates the compound to nullify pointers, leaving the compound in an unusable state.