b3CreateCapsuleShape

Function b3CreateCapsuleShape 

pub unsafe extern "C" fn b3CreateCapsuleShape(
    bodyId: b3BodyId,
    def: *const b3ShapeDef,
    capsule: *const b3Capsule,
) -> b3ShapeId
Create a capsule shape and attach it to a body. The shape definition and geometry are fully cloned. Contacts are not created until the next time step. @return the shape id for accessing the shape