pub unsafe extern "C" fn b3CreateCompound(
def: *const b3CompoundDef,
) -> *mut b3CompoundDataExpand description
Create a compound shape. All input data in the definition is cloned into the resulting compound.
pub unsafe extern "C" fn b3CreateCompound(
def: *const b3CompoundDef,
) -> *mut b3CompoundDataCreate a compound shape. All input data in the definition is cloned into the resulting compound.