b3CreateGridMesh

Function b3CreateGridMesh 

pub unsafe extern "C" fn b3CreateGridMesh(
    xCount: c_int,
    zCount: c_int,
    cellWidth: f32,
    materialCount: c_int,
    identifyEdges: bool,
) -> *mut b3MeshData
Create a grid mesh along the x and z axes. @param xCount the number of rows in the x direction @param zCount the number of rows in the z direction @param cellWidth the width of each cell @param materialCount the number of materials to generate @param identifyEdges compute adjacency information