b3CreateHeightFieldShape

Function b3CreateHeightFieldShape 

pub unsafe extern "C" fn b3CreateHeightFieldShape(
    bodyId: b3BodyId,
    def: *const b3ShapeDef,
    heightField: *const b3HeightFieldData,
) -> b3ShapeId
Create a height-field shape and attach it to a body. The shape definition is fully cloned but the height field is not. Contacts are not created until the next time step. Height field is only allowed on static bodies. @warning this holds reference to the input height field which must remain valid for the lifetime of this shape @return the shape id for accessing the shape