pub unsafe extern "C" fn b3CreateHullShape(
bodyId: b3BodyId,
def: *const b3ShapeDef,
hull: *const b3HullData,
) -> b3ShapeIdExpand description
Create a convex hull shape and attach it to a body. The shape definition is fully cloned. Contacts are not created until the next time step. @return the shape id for accessing the shape