b3CreateMeshShape

Function b3CreateMeshShape 

pub unsafe extern "C" fn b3CreateMeshShape(
    bodyId: b3BodyId,
    def: *const b3ShapeDef,
    mesh: *const b3MeshData,
    scale: b3Vec3,
) -> b3ShapeId
Create a mesh hull shape and attach it to a body. The shape definition is fully cloned but the mesh is not. Contacts are not created until the next time step. Mesh collision only creates contacts on static bodies. @warning this holds reference to the input mesh data which must remain valid for the lifetime of this shape @return the shape id for accessing the shape