b3CreateSphereShape

Function b3CreateSphereShape 

pub unsafe extern "C" fn b3CreateSphereShape(
    bodyId: b3BodyId,
    def: *const b3ShapeDef,
    sphere: *const b3Sphere,
) -> b3ShapeId
Create a circle shape and attach it to a body. The shape definition and geometry are fully cloned. Contacts are not created until the next time step. @return the shape id for accessing the shape