b3DestroyBody

Function b3DestroyBody 

pub unsafe extern "C" fn b3DestroyBody(bodyId: b3BodyId)
Destroy a rigid body given an id. This destroys all shapes and joints attached to the body. Do not keep references to the associated shapes and joints.