pub unsafe extern "C" fn b3DestroyShape(
shapeId: b3ShapeId,
updateBodyMass: bool,
)Expand description
Destroy a shape. You may defer the body mass update which can improve performance if several shapes on a body are destroyed at once. @see b3Body_ApplyMassFromShapes