b3DistanceJoint_EnableLimit

Function b3DistanceJoint_EnableLimit 

pub unsafe extern "C" fn b3DistanceJoint_EnableLimit(
    jointId: b3JointId,
    enableLimit: bool,
)
Enable joint limit. The limit only works if the joint spring is enabled. Otherwise the joint is rigid and the limit has no effect.