pub unsafe extern "C" fn b3DynamicTree_GetRootBounds(
tree: *const b3DynamicTree,
) -> b3AABBExpand description
Get the bounding box that contains the entire tree
pub unsafe extern "C" fn b3DynamicTree_GetRootBounds(
tree: *const b3DynamicTree,
) -> b3AABBGet the bounding box that contains the entire tree