pub unsafe extern "C" fn b3GetGraphColor(index: c_int) -> b3HexColorExpand description
Get the visualization color assigned to a constraint graph color slot. The last index (B3_GRAPH_COLOR_COUNT - 1) is the overflow color.
pub unsafe extern "C" fn b3GetGraphColor(index: c_int) -> b3HexColorGet the visualization color assigned to a constraint graph color slot. The last index (B3_GRAPH_COLOR_COUNT - 1) is the overflow color.