pub unsafe extern "C" fn b3IsValidRay(
input: *const b3RayCastInput,
) -> boolExpand description
Use this to ensure your ray cast input is valid and avoid internal assertions.
pub unsafe extern "C" fn b3IsValidRay(
input: *const b3RayCastInput,
) -> boolUse this to ensure your ray cast input is valid and avoid internal assertions.