pub unsafe extern "C" fn b3MakeScaledBoxHull(
halfWidths: b3Vec3,
transform: b3Transform,
postScale: b3Vec3,
) -> b3BoxHullExpand description
This makes a transformed box hull with post scaling. This is useful for boxes that are scaled in a level editor. Such scaling can have reflection and shear. In the case of shear the result may be approximate. If you need to support shear consider using b3CreateHull. Do not call b3DestroyHull on this. @param halfWidths positive half widths @param transform local transform of box @param postScale scale applied after the transform, may be negative