pub unsafe extern "C" fn b3QueryCompound(
compound: *const b3CompoundData,
aabb: b3AABB,
fcn: b3CompoundQueryFcn,
context: *mut c_void,
)Expand description
Query a compound shape for children that overlap an AABB.
pub unsafe extern "C" fn b3QueryCompound(
compound: *const b3CompoundData,
aabb: b3AABB,
fcn: b3CompoundQueryFcn,
context: *mut c_void,
)Query a compound shape for children that overlap an AABB.