pub unsafe extern "C" fn b3QueryMesh(
mesh: *const b3Mesh,
bounds: b3AABB,
fcn: b3MeshQueryFcn,
context: *mut c_void,
)Expand description
Query a mesh for triangles overlapping a bounding box in local space. May have false positives. Useful for debug draw. @param mesh the mesh to query, includes scale @param bounds the bounding box in local space @param fcn a user function to collect triangles @param context the context sent to the user function.