b3RayCastCompound

Function b3RayCastCompound 

pub unsafe extern "C" fn b3RayCastCompound(
    shape: *const b3CompoundData,
    input: *const b3RayCastInput,
) -> b3CastOutput
Ray cast versus compound in local space. A zero length ray is a point query. Initial overlap with a child reports a hit at the ray origin with zero fraction and zero normal.