pub unsafe extern "C" fn b3RayCastMesh(
shape: *const b3Mesh,
input: *const b3RayCastInput,
) -> b3CastOutputExpand description
Ray cast versus mesh in local space. A thin surface with no interior, so there is no overlap case.
pub unsafe extern "C" fn b3RayCastMesh(
shape: *const b3Mesh,
input: *const b3RayCastInput,
) -> b3CastOutputRay cast versus mesh in local space. A thin surface with no interior, so there is no overlap case.