pub unsafe extern "C" fn b3RecPlayer_GetBodyCount(
player: *const b3RecPlayer,
) -> c_intExpand description
@return the number of bodies tracked in creation order (including holes for destroyed bodies)
pub unsafe extern "C" fn b3RecPlayer_GetBodyCount(
player: *const b3RecPlayer,
) -> c_int@return the number of bodies tracked in creation order (including holes for destroyed bodies)