pub unsafe extern "C" fn b3RecPlayer_GetBodyId(
player: *const b3RecPlayer,
index: c_int,
) -> b3BodyIdExpand description
Resolve a creation ordinal to the live body id at the current frame. @return the body id, or a null id if that ordinal is out of range or its body is destroyed