pub unsafe extern "C" fn b3RecPlayer_GetFrameQuery(
player: *const b3RecPlayer,
index: c_int,
) -> b3RecQueryInfoExpand description
Get a recorded query from the most recently replayed frame by index.
pub unsafe extern "C" fn b3RecPlayer_GetFrameQuery(
player: *const b3RecPlayer,
index: c_int,
) -> b3RecQueryInfoGet a recorded query from the most recently replayed frame by index.