pub unsafe extern "C" fn b3RecPlayer_GetFrameQueryCount(
player: *const b3RecPlayer,
) -> c_intExpand description
@return the number of spatial queries recorded for the most recently replayed frame
pub unsafe extern "C" fn b3RecPlayer_GetFrameQueryCount(
player: *const b3RecPlayer,
) -> c_int@return the number of spatial queries recorded for the most recently replayed frame