pub unsafe extern "C" fn b3RecPlayer_GetFrameQueryHit(
player: *const b3RecPlayer,
queryIndex: c_int,
hitIndex: c_int,
) -> b3RecQueryHitExpand description
Get one result of a recorded query from the most recently replayed frame.
pub unsafe extern "C" fn b3RecPlayer_GetFrameQueryHit(
player: *const b3RecPlayer,
queryIndex: c_int,
hitIndex: c_int,
) -> b3RecQueryHitGet one result of a recorded query from the most recently replayed frame.