pub unsafe extern "C" fn b3RecPlayer_GetKeyframeBytes(
player: *const b3RecPlayer,
) -> usizeExpand description
@return the memory currently held by keyframe snapshots, in bytes
pub unsafe extern "C" fn b3RecPlayer_GetKeyframeBytes(
player: *const b3RecPlayer,
) -> usize@return the memory currently held by keyframe snapshots, in bytes