pub unsafe extern "C" fn b3RecPlayer_IsAtPreStep(
player: *const b3RecPlayer,
) -> boolExpand description
@return true when the op stream is paused between body creation and world step.
pub unsafe extern "C" fn b3RecPlayer_IsAtPreStep(
player: *const b3RecPlayer,
) -> bool@return true when the op stream is paused between body creation and world step.