pub unsafe extern "C" fn b3Recording_GetSize(
recording: *const b3Recording,
) -> c_intExpand description
Get the number of bytes currently in the recording buffer. @param recording the recording handle
pub unsafe extern "C" fn b3Recording_GetSize(
recording: *const b3Recording,
) -> c_intGet the number of bytes currently in the recording buffer. @param recording the recording handle