pub unsafe extern "C" fn b3SetAllocator(
allocFcn: b3AllocFcn,
freeFcn: b3FreeFcn,
)Expand description
This allows the user to override the allocation functions. These should be set during application startup.
pub unsafe extern "C" fn b3SetAllocator(
allocFcn: b3AllocFcn,
freeFcn: b3FreeFcn,
)This allows the user to override the allocation functions. These should be set during application startup.