b3SetLengthUnitsPerMeter

Function b3SetLengthUnitsPerMeter 

pub unsafe extern "C" fn b3SetLengthUnitsPerMeter(lengthUnits: f32)
Box3D bases all length units on meters, but you may need different units for your game. You can set this value to use different units. This should be done at application startup and only modified once. Default value is 1. @warning This must be modified before any calls to Box3D