b3ShapeDistance

Function b3ShapeDistance 

pub unsafe extern "C" fn b3ShapeDistance(
    input: *const b3DistanceInput,
    cache: *mut b3SimplexCache,
    simplexes: *mut b3Simplex,
    simplexCapacity: c_int,
) -> b3DistanceOutput
Compute the closest points between two shapes represented as point clouds. b3SimplexCache cache is input/output. On the first call set b3SimplexCache.count to zero. The query runs in frame A, so the witness points and normal are returned in frame A. The underlying GJK algorithm may be debugged by passing in debug simplexes and capacity. You may pass in NULL and 0 for these.