b3Shape_ApplyWind

Function b3Shape_ApplyWind 

pub unsafe extern "C" fn b3Shape_ApplyWind(
    shapeId: b3ShapeId,
    wind: b3Vec3,
    drag: f32,
    lift: f32,
    maxSpeed: f32,
    wake: bool,
)
Apply a wind force to the body for this shape using the density of air. This considers the projected area of the shape in the wind direction. This also considers the relative velocity of the shape. @param shapeId the shape id @param wind the wind velocity in world space @param drag the drag coefficient, the force that opposes the relative velocity @param lift the lift coefficient, the force that is perpendicular to the relative velocity @param maxSpeed the maximum relative speed. Speed cap is necessary for stability. Typically 10m/s or less. @param wake should this wake the body