b3Shape_GetSensorData

Function b3Shape_GetSensorData 

pub unsafe extern "C" fn b3Shape_GetSensorData(
    shapeId: b3ShapeId,
    visitorIds: *mut b3ShapeId,
    capacity: c_int,
) -> c_int
Get the overlap data for a sensor shape. @param shapeId the id of a sensor shape @param visitorIds a user allocated array that is filled with the overlapping shapes (visitors) @param capacity the capacity of overlappedShapes @returns the number of elements filled in the provided array @warning do not ignore the return value, it specifies the valid number of elements @warning overlaps may contain destroyed shapes so use b3Shape_IsValid to confirm each overlap