pub unsafe extern "C" fn b3Shape_SetDensity(
shapeId: b3ShapeId,
density: f32,
updateBodyMass: bool,
)Expand description
Set the mass density of a shape, usually in kg/m^3. This will optionally update the mass properties on the parent body. @see b3ShapeDef::density, b3Body_ApplyMassFromShapes