b3Shape_SetFilter

Function b3Shape_SetFilter 

pub unsafe extern "C" fn b3Shape_SetFilter(
    shapeId: b3ShapeId,
    filter: b3Filter,
    invokeContacts: bool,
)
Set the current filter. This is almost as expensive as recreating the shape. @see b3ShapeDef::filter @param shapeId the shape @param filter the new filter @param invokeContacts if true then the shape will have all contacts recomputed the next time step (expensive)