b3TimeOfImpact

Function b3TimeOfImpact 

pub unsafe extern "C" fn b3TimeOfImpact(
    input: *const b3TOIInput,
) -> b3TOIOutput
Compute the upper bound on time before two shapes penetrate. Time is represented as a fraction between [0,tMax]. This uses a swept separating axis and may miss some intermediate, non-tunneling collisions. If you change the time interval, you should call this function again.