b3World_CastMover

Function b3World_CastMover 

pub unsafe extern "C" fn b3World_CastMover(
    worldId: b3WorldId,
    origin: b3Pos,
    mover: *const b3Capsule,
    translation: b3Vec3,
    filter: b3QueryFilter,
    fcn: b3MoverFilterFcn,
    context: *mut c_void,
) -> f32
Cast a capsule mover through the world. This is a special shape cast that handles sliding along other shapes while reducing clipping. This is not a good source of information about what the mover is touching. Instead use the planes returned by b3World_CollideMover. @param worldId World to cast the mover against @param origin World position the mover capsule is relative to @param mover Capsule mover, relative to the origin @param translation Desired mover translation @param filter Contains bit flags to filter unwanted shapes from the results @param fcn Optional callback for custom shape filtering @param context A user context that is passed along to the callback function @return the translation fraction