pub unsafe extern "C" fn b3World_CastShape(
worldId: b3WorldId,
origin: b3Pos,
proxy: *const b3ShapeProxy,
translation: b3Vec3,
filter: b3QueryFilter,
fcn: b3CastResultFcn,
context: *mut c_void,
) -> b3TreeStatsExpand description
Cast a shape through the world. Similar to a cast ray except that a shape is cast instead of a point. The proxy points are relative to the origin and the hit points come back as world positions, so the cast stays precise far from the world origin. @see b3World_CastRay