b3World_CollideMover

Function b3World_CollideMover 

pub unsafe extern "C" fn b3World_CollideMover(
    worldId: b3WorldId,
    origin: b3Pos,
    mover: *const b3Capsule,
    filter: b3QueryFilter,
    fcn: b3PlaneResultFcn,
    context: *mut c_void,
)
Collide a capsule mover with the world, gathering collision planes that can be fed to b3SolvePlanes. Useful for kinematic character movement. The mover and the returned planes are relative to the origin.