pub unsafe extern "C" fn b3World_Draw(
worldId: b3WorldId,
draw: *mut b3DebugDraw,
maskBits: u64,
)Expand description
Call this to draw shapes and other debug draw data
pub unsafe extern "C" fn b3World_Draw(
worldId: b3WorldId,
draw: *mut b3DebugDraw,
maskBits: u64,
)Call this to draw shapes and other debug draw data