pub unsafe extern "C" fn b3World_GetBodyEvents(
worldId: b3WorldId,
) -> b3BodyEventsExpand description
Get the body events for the current time step. The event data is transient. Do not store a reference to this data.
pub unsafe extern "C" fn b3World_GetBodyEvents(
worldId: b3WorldId,
) -> b3BodyEventsGet the body events for the current time step. The event data is transient. Do not store a reference to this data.