b3World_SetGravity

Function b3World_SetGravity 

pub unsafe extern "C" fn b3World_SetGravity(
    worldId: b3WorldId,
    gravity: b3Vec3,
)
Set the gravity vector for the entire world. Box3D has no concept of an up direction and this is left as a decision for the application. Usually in m/s^2. @see b3WorldDef