#[repr(C)]pub struct b3BodyCastResult {
pub shapeId: b3ShapeId,
pub point: b3Pos,
pub normal: b3Vec3,
pub fraction: f32,
pub triangleIndex: c_int,
pub userMaterialId: u64,
pub iterations: c_int,
pub hit: bool,
}Expand description
Body cast result for ray and shape casts.
Fields
shapeId: b3ShapeIdThe shape hit.
point: b3PosThe world point on the shape surface.
normal: b3Vec3The world normal vector on the shape surface.
fraction: f32The fraction along the ray hit. hit point = origin + fraction * translation
triangleIndex: c_intThe triangle index if the shape is a mesh or height-field.
userMaterialId: u64The user material id at the hit point. This can be per triangle if the shape is a mesh, height-field, or compound with child mesh.
iterations: c_intThe number of iterations used. Diagnostic.
hit: boolDid the cast hit? If false, all other fields are invalid.