#[repr(C)]pub struct b3BodyEvents {
pub moveEvents: *mut b3BodyMoveEvent,
pub moveCount: c_int,
}Expand description
Body events are buffered in the world and are available as event arrays after the time step is complete. Note: this data becomes invalid if bodies are destroyed
Fields
moveEvents: *mut b3BodyMoveEventArray of move events
moveCount: c_intNumber of move events