#[repr(C)]pub struct b3CollisionPlane {
pub plane: b3Plane,
pub pushLimit: f32,
pub push: f32,
pub clipVelocity: bool,
}Expand description
These are collision planes that can be fed to b3SolvePlanes. Normally this is assembled by the user from plane results in b3PlaneResult.
Fields
plane: b3PlaneThe collision plane between the mover and some shape.
pushLimit: f32Setting this to FLT_MAX makes the plane as rigid as possible. Lower values can make the plane collision soft. Usually in meters.
push: f32The push on the mover determined by b3SolvePlanes. Usually in meters.
clipVelocity: boolIndicates if b3ClipVector should clip against this plane. Should be false for soft collision.