#[repr(C)]pub struct b3CompoundData {Show 16 fields
pub version: u64,
pub byteCount: c_int,
pub nodeOffset: c_int,
pub tree: b3DynamicTree,
pub materialOffset: c_int,
pub materialCount: c_int,
pub capsuleOffset: c_int,
pub capsuleCount: c_int,
pub hullOffset: c_int,
pub hullCount: c_int,
pub sharedHullCount: c_int,
pub meshOffset: c_int,
pub meshCount: c_int,
pub sharedMeshCount: c_int,
pub sphereOffset: c_int,
pub sphereCount: c_int,
}Expand description
The runtime data for a compound shape. This is a potentially large yet highly optimized data structure. It can contain thousands of child shapes, yet at runtime it populates into the world as a single shape in the runtime broad-phase. This data structure has data living off the end and must be accessed using offsets. Accessors are provided for user relevant data.
Fields
version: u64The compound version is always first.
byteCount: c_intThe total number of bytes for this compound.
nodeOffset: c_intOffset of the tree node array in bytes from the struct address.
tree: b3DynamicTreeImmutable dynamic tree. The tree node pointer must be fixed up using the node offset
materialOffset: c_intOffset of the material array in bytes from the struct address.
materialCount: c_intThe number of materials.
capsuleOffset: c_intOffset of the capsule array in bytes from the struct address.
capsuleCount: c_intThe number of capsules.
hullOffset: c_intOffset of the hull instance array in bytes from the struct address.
hullCount: c_intThe number of hull instances.
The number of unique hulls. Diagnostic.
meshOffset: c_intOffset of the mesh instance array in bytes from the struct address.
meshCount: c_intThe number of mesh instances.
The number of unique meshes. Diagnostic.
sphereOffset: c_intOffset of the sphere array in bytes from the struct address.
sphereCount: c_intThe number of spheres.