#[repr(C)]pub struct b3CompoundHullDef {
pub hull: *const b3HullData,
pub transform: b3Transform,
pub material: b3SurfaceMaterial,
}Expand description
Definition for a convex hull in a compound shape.
Fields
hull: *const b3HullDataShared hull.
transform: b3TransformTransform of the shared hull into compound local space.
material: b3SurfaceMaterialMaterial properties.