#[repr(C)]pub struct b3CompoundMeshDef {
pub meshData: *const b3MeshData,
pub transform: b3Transform,
pub scale: b3Vec3,
pub materials: *const b3SurfaceMaterial,
pub materialCount: c_int,
}Expand description
Definition for a triangle mesh in a compound shape.
Fields
meshData: *const b3MeshDataShared mesh.
transform: b3TransformTransform of the shared mesh into compound local space.
scale: b3Vec3Local space non-uniform mesh scale. May have negative components.
materials: *const b3SurfaceMaterialMaterial properties. This array must line up with the material indices on the triangles.
materialCount: c_intNumber of materials.