#[repr(C)]pub struct b3ContactBeginTouchEvent {
pub shapeIdA: b3ShapeId,
pub shapeIdB: b3ShapeId,
pub contactId: b3ContactId,
}Expand description
A begin-touch event is generated when two shapes begin touching.
Fields
shapeIdA: b3ShapeIdId of the first shape
shapeIdB: b3ShapeIdId of the second shape
contactId: b3ContactIdThe transient contact id. This contact may be destroyed automatically when the world is modified or simulated. Use b3Contact_IsValid before using this id.