#[repr(C)]pub struct b3ContactData {
pub contactId: b3ContactId,
pub shapeIdA: b3ShapeId,
pub shapeIdB: b3ShapeId,
pub manifolds: *const b3Manifold,
pub manifoldCount: c_int,
}Expand description
The contact data for two shapes. By convention the manifold normal points from shape A to shape B. @see b3Shape_GetContactData() and b3Body_GetContactData()
Fields
contactId: b3ContactIdThe contact id. You may hold onto this to track a contact across time steps. This id may become orphaned. Use b3Contact_IsValid before using it for other functions.
shapeIdA: b3ShapeIdThe first shape id.
shapeIdB: b3ShapeIdThe second shape id.
manifolds: *const b3ManifoldThe contact manifold. This points to internal data and may become invalid. Do not store this pointer.
manifoldCount: c_intThe number of contact manifolds. For mesh and height-field collision there can be multiple manifolds.