#[repr(C)]pub struct b3ContactEndTouchEvent {
pub shapeIdA: b3ShapeId,
pub shapeIdB: b3ShapeId,
pub contactId: b3ContactId,
}Expand description
An end touch event is generated when two shapes stop touching. You will get an end event if you do anything that destroys contacts previous to the last world step. These include things like setting the transform, destroying a body or shape, or changing a filter or body type.
Fields
shapeIdA: b3ShapeIdId of the first shape @warning this shape may have been destroyed @see b3Shape_IsValid
shapeIdB: b3ShapeIdId of the first shape @warning this shape may have been destroyed @see b3Shape_IsValid
contactId: b3ContactIdId of the contact. @warning this contact may have been destroyed @see b3Contact_IsValid