#[repr(C)]pub struct b3ContactEvents {
pub beginEvents: *mut b3ContactBeginTouchEvent,
pub endEvents: *mut b3ContactEndTouchEvent,
pub hitEvents: *mut b3ContactHitEvent,
pub beginCount: c_int,
pub endCount: c_int,
pub hitCount: c_int,
}Expand description
Contact events are buffered in the world and are available as event arrays after the time step is complete. Note: these may become invalid if bodies and/or shapes are destroyed
Fields
beginEvents: *mut b3ContactBeginTouchEventArray of begin touch events
endEvents: *mut b3ContactEndTouchEventArray of end touch events
hitEvents: *mut b3ContactHitEventArray of hit events
beginCount: c_intNumber of begin touch events
endCount: c_intNumber of end touch events
hitCount: c_intNumber of hit events