#[repr(C)]pub struct b3Counters {Show 20 fields
pub bodyCount: c_int,
pub shapeCount: c_int,
pub contactCount: c_int,
pub jointCount: c_int,
pub islandCount: c_int,
pub stackUsed: c_int,
pub arenaCapacity: c_int,
pub staticTreeHeight: c_int,
pub treeHeight: c_int,
pub satCallCount: c_int,
pub satCacheHitCount: c_int,
pub byteCount: c_int,
pub taskCount: c_int,
pub colorCounts: [c_int; 24],
pub manifoldCounts: [c_int; 8],
pub awakeContactCount: c_int,
pub recycledContactCount: c_int,
pub distanceIterations: c_int,
pub pushBackIterations: c_int,
pub rootIterations: c_int,
}Expand description
Counters that give details of the simulation size. @ingroup world
Fields
bodyCount: c_intshapeCount: c_intcontactCount: c_intjointCount: c_intislandCount: c_intstackUsed: c_intarenaCapacity: c_intstaticTreeHeight: c_inttreeHeight: c_intsatCallCount: c_intsatCacheHitCount: c_intbyteCount: c_inttaskCount: c_intcolorCounts: [c_int; 24]manifoldCounts: [c_int; 8]awakeContactCount: c_intNumber of contacts touched by the collide pass graph contacts + awake-set non-touching
recycledContactCount: c_intNumber of contacts recycled in the most recent step.
distanceIterations: c_intMaximum number of time of impact iterations
pushBackIterations: c_introotIterations: c_intTrait Implementations
Sourceimpl Clone for b3Counters
impl Clone for b3Counters
Sourcefn clone(&self) -> b3Counters
fn clone(&self) -> b3Counters
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for b3Counters