#[repr(C)]pub struct b3DebugShape {
pub shapeId: b3ShapeId,
pub type_: b3ShapeType,
pub __bindgen_anon_1: b3DebugShape__bindgen_ty_1,
}Expand description
This is sent to the user for debug shape creation. The user should know the type in case they have custom sphere or capsule rendering.
Fields
shapeId: b3ShapeIdShape id.
type_: b3ShapeTypeShape type.
__bindgen_anon_1: b3DebugShape__bindgen_ty_1Trait Implementations
Sourceimpl Clone for b3DebugShape
impl Clone for b3DebugShape
Sourcefn clone(&self) -> b3DebugShape
fn clone(&self) -> b3DebugShape
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for b3DebugShape