#[repr(C)]pub struct b3ExplosionDef {
pub maskBits: u64,
pub position: b3Pos,
pub radius: f32,
pub falloff: f32,
pub impulsePerArea: f32,
}Expand description
The explosion definition is used to configure options for explosions. Explosions consider shape geometry when computing the impulse. @ingroup world
Fields
maskBits: u64Mask bits to filter shapes
position: b3PosThe center of the explosion in world space
radius: f32The radius of the explosion
falloff: f32The falloff distance beyond the radius. Impulse is reduced to zero at this distance.
impulsePerArea: f32Impulse per unit area. This applies an impulse according to the shape area that is facing the explosion. Explosions only apply to spheres, capsules, and hulls. This may be negative for implosions.