b3FeaturePair

Struct b3FeaturePair 

#[repr(C)]
pub struct b3FeaturePair { pub owner1: u8, pub index1: u8, pub owner2: u8, pub index2: u8, }
Contact points are always the result of two edges intersecting. It can be two edges of the same shape, which is just a shape vertex. Or a contact point can be the result of two edges crossing from different shapes. This is designed to support hull versus hull, but it is adapted to work with all shape types. The feature pair is used to identify contact points for temporal coherence and warm starting.

Fields

owner1: u8

Incoming type (either edge on shape A or shape B)

index1: u8

Incoming edge index (into associated shape array)

owner2: u8

Outgoing type (either edge on shape A or shape B)

index2: u8

Outgoing edge index (into associated shape array)