b3HullVertex

Struct b3HullVertex 

#[repr(C)]
pub struct b3HullVertex { pub edge: u8, }
A hull vertex. Identified by a half-edge with this vertex as its tail.

Fields

edge: u8

A half-edge that has this vertex as the origin Can be used along with edge twins and winding order to traverse all the edges connected to this vertex.