#[repr(C)]pub struct b3JointDef {
pub userData: *mut c_void,
pub bodyIdA: b3BodyId,
pub bodyIdB: b3BodyId,
pub localFrameA: b3Transform,
pub localFrameB: b3Transform,
pub forceThreshold: f32,
pub torqueThreshold: f32,
pub constraintHertz: f32,
pub constraintDampingRatio: f32,
pub drawScale: f32,
pub collideConnected: bool,
pub internalValue: c_int,
}Expand description
Base joint definition used by all joint types. The local frames are measured from the body’s origin rather than the center of mass because:
- You might not know where the center of mass will be.
- If you add/remove shapes from a body and recompute the mass, the joints will be broken. @ingroup joint
Fields
userData: *mut c_voidUser data pointer
bodyIdA: b3BodyIdThe first attached body
bodyIdB: b3BodyIdThe second attached body
localFrameA: b3TransformThe first local joint frame
localFrameB: b3TransformThe second local joint frame
forceThreshold: f32Force threshold for joint events
torqueThreshold: f32Torque threshold for joint events
constraintHertz: f32Constraint hertz (advanced feature)
constraintDampingRatio: f32Constraint damping ratio (advanced feature)
drawScale: f32Debug draw scale
collideConnected: boolSet this flag to true if the attached bodies should collide
internalValue: c_intUsed internally to detect a valid definition. DO NOT SET.