#[repr(C)]pub struct b3JointEvent {
pub jointId: b3JointId,
pub userData: *mut c_void,
}Expand description
Joint events report joints that are awake and have a force and/or torque exceeding the threshold The observed forces and torques are not returned for efficiency reasons.
Fields
jointId: b3JointIdThe joint id
userData: *mut c_voidThe user data from the joint for convenience