#[repr(C)]pub struct b3JointEvents {
pub jointEvents: *mut b3JointEvent,
pub count: c_int,
}Expand description
Joint events are buffered in the world and are available as event arrays after the time step is complete. Note: this data becomes invalid if joints are destroyed
Fields
jointEvents: *mut b3JointEventArray of events
count: c_intNumber of events