#[repr(C)]pub struct b3LocalManifoldPoint {
pub point: b3Vec3,
pub separation: f32,
pub pair: b3FeaturePair,
pub triangleIndex: c_int,
}Expand description
A local manifold point and normal in frame A.
Fields
point: b3Vec3Local point in frame A.
separation: f32The contact point separation. Negative for overlap.
pair: b3FeaturePairThe feature pair for this point.
triangleIndex: c_intThe triangle index when collide with a mesh or height-field.