#[repr(C)]pub struct b3MassData {
pub mass: f32,
pub center: b3Vec3,
pub inertia: b3Matrix3,
}Expand description
This holds the mass data computed for a shape.
Fields
mass: f32The shape mass
center: b3Vec3The local center of mass position.
inertia: b3Matrix3The inertia tensor about the shape center of mass.