b3MeshData

Struct b3MeshData 

#[repr(C)]
pub struct b3MeshData {
Show 16 fields pub version: u64, pub byteCount: c_int, pub hash: u32, pub bounds: b3AABB, pub surfaceArea: f32, pub treeHeight: c_int, pub degenerateCount: c_int, pub nodeOffset: c_int, pub nodeCount: c_int, pub vertexOffset: c_int, pub vertexCount: c_int, pub triangleOffset: c_int, pub triangleCount: c_int, pub materialOffset: c_int, pub materialCount: c_int, pub flagsOffset: c_int,
}
This is a sorted triangle collision bounding volume hierarchy. @note This struct has data hanging off the end and cannot be directly copied.

Fields

version: u64

Version must be first.

byteCount: c_int

The total number of bytes for this mesh.

hash: u32

Hash of this mesh (this field is zero when the hash is computed)

bounds: b3AABB

Local axis-aligned box.

surfaceArea: f32

Combined surface area of all triangles. Single-sided.

treeHeight: c_int

The height of the bounding volume hierarchy.

degenerateCount: c_int

The number of degenerate triangles. Diagnostic.

nodeOffset: c_int

Offset of the node array in bytes from the struct address.

nodeCount: c_int

The number of BVH nodes.

vertexOffset: c_int

Offset of the vertex array in bytes from the struct address.

vertexCount: c_int

The number of vertices.

triangleOffset: c_int

Offset of the triangle array in bytes from the struct address.

triangleCount: c_int

The number of triangles.

materialOffset: c_int

Offset of the material array in bytes from the struct address.

materialCount: c_int

The number of materials.

flagsOffset: c_int

Offset of the triangle flag array in bytes from the struct address.