#[repr(C)]pub struct b3ParallelJointDef {
pub base: b3JointDef,
pub hertz: f32,
pub dampingRatio: f32,
pub maxTorque: f32,
}Expand description
Parallel joint definition. Constrains the angle between axis z in body A and axis z in body B using a spring. Useful to keep a body upright. @ingroup parallel_joint
Fields
base: b3JointDefBase joint definition
hertz: f32The spring stiffness Hertz, cycles per second
dampingRatio: f32The spring damping ratio, non-dimensional
maxTorque: f32The maximum spring torque, typically in newton-meters.