#[repr(C)]pub struct b3PrismaticJointDef {
pub base: b3JointDef,
pub enableSpring: bool,
pub hertz: f32,
pub dampingRatio: f32,
pub targetTranslation: f32,
pub enableLimit: bool,
pub lowerTranslation: f32,
pub upperTranslation: f32,
pub enableMotor: bool,
pub maxMotorForce: f32,
pub motorSpeed: f32,
}Expand description
Prismatic joint definition. Body B may slide along the x-axis in local frame A. Body B cannot rotate relative to body A. The joint translation is zero when the local frame origins coincide in world space. @ingroup prismatic_joint
Fields
base: b3JointDefBase joint definition
enableSpring: boolEnable a linear spring along the prismatic joint axis
hertz: f32The spring stiffness Hertz, cycles per second
dampingRatio: f32The spring damping ratio, non-dimensional
targetTranslation: f32The target translation for the joint in meters. The spring-damper will drive to this translation.
enableLimit: boolEnable/disable the joint limit
lowerTranslation: f32The lower translation limit
upperTranslation: f32The upper translation limit
enableMotor: boolEnable/disable the joint motor
maxMotorForce: f32The maximum motor force, typically in newtons
motorSpeed: f32The desired motor speed, typically in meters per second