b3RevoluteJointDef

Struct b3RevoluteJointDef 

#[repr(C)]
pub struct b3RevoluteJointDef { pub base: b3JointDef, pub targetAngle: f32, pub enableSpring: bool, pub hertz: f32, pub dampingRatio: f32, pub enableLimit: bool, pub lowerAngle: f32, pub upperAngle: f32, pub enableMotor: bool, pub maxMotorTorque: f32, pub motorSpeed: f32, }
Revolute joint definition. A point on body B is fixed to a point on body A. Allows relative rotation about the z-axis. @ingroup revolute_joint

Fields

base: b3JointDef

Base joint definition.

targetAngle: f32

The bodyB angle minus bodyA angle in the reference state (radians). This defines the zero angle for the joint limit.

enableSpring: bool

Enable a rotational spring on the revolute hinge axis.

hertz: f32

The spring stiffness Hertz, cycles per second.

dampingRatio: f32

The spring damping ratio, non-dimensional.

enableLimit: bool

A flag to enable joint limits.

lowerAngle: f32

The lower angle for the joint limit in radians. Minimum of -0.99*pi radians.

upperAngle: f32

The upper angle for the joint limit in radians. Maximum of 0.99*pi radians.

enableMotor: bool

A flag to enable the joint motor.

maxMotorTorque: f32

The maximum motor torque, typically in newton-meters.

motorSpeed: f32

The desired motor speed in radians per second.