#[repr(C)]pub struct b3SensorBeginTouchEvent {
pub sensorShapeId: b3ShapeId,
pub visitorShapeId: b3ShapeId,
}Expand description
A begin-touch event is generated when a shape starts to overlap a sensor shape.
Fields
sensorShapeId: b3ShapeIdThe id of the sensor shape
visitorShapeId: b3ShapeIdThe id of the shape that began touching the sensor shape