#[repr(C)]pub struct b3SensorEndTouchEvent {
pub sensorShapeId: b3ShapeId,
pub visitorShapeId: b3ShapeId,
}Expand description
An end touch event is generated when a shape stops overlapping a sensor shape. These include things like setting the transform, destroying a body or shape, or changing a filter. You will also get an end event if the sensor or visitor are destroyed. Therefore you should always confirm the shape id is valid using b3Shape_IsValid.
Fields
sensorShapeId: b3ShapeIdThe id of the sensor shape @warning this shape may have been destroyed @see b3Shape_IsValid
visitorShapeId: b3ShapeIdThe id of the shape that stopped touching the sensor shape @warning this shape may have been destroyed @see b3Shape_IsValid