#[repr(C)]pub struct b3SensorEvents {
pub beginEvents: *mut b3SensorBeginTouchEvent,
pub endEvents: *mut b3SensorEndTouchEvent,
pub beginCount: c_int,
pub endCount: c_int,
}Expand description
Sensor events are buffered in the world and are available as begin/end overlap event arrays after the time step is complete. Note: these may become invalid if bodies and/or shapes are destroyed
Fields
beginEvents: *mut b3SensorBeginTouchEventArray of sensor begin touch events
endEvents: *mut b3SensorEndTouchEventArray of sensor end touch events
beginCount: c_intThe number of begin touch events
endCount: c_intThe number of end touch events