#[repr(C)]pub struct b3ShapeCastInput {
pub proxy: b3ShapeProxy,
pub translation: b3Vec3,
pub maxFraction: f32,
pub canEncroach: bool,
}Expand description
Low level shape cast input in generic form. This allows casting an arbitrary point cloud wrap with a radius. For example, a sphere is a single point with a non-zero radius. A capsule is two points with a non-zero radius. A box is four points with a zero radius.
Fields
proxy: b3ShapeProxyA generic query shape.
translation: b3Vec3The translation of the shape cast.
maxFraction: f32The maximum fraction of the translation to consider, typically 1.
canEncroach: boolAllow shape cast to encroach when initially touching. This only works if the radius is greater than zero.