#[repr(C)]pub struct b3ShapeCastPairInput {
pub proxyA: b3ShapeProxy,
pub proxyB: b3ShapeProxy,
pub transform: b3Transform,
pub translationB: b3Vec3,
pub maxFraction: f32,
pub canEncroach: bool,
}Expand description
Input parameters for b3ShapeCast
Fields
proxyA: b3ShapeProxy< The proxy for shape A
proxyB: b3ShapeProxy< The proxy for shape B
transform: b3Transform< Transform of shape B in shape A’s frame, the relative pose B in A
translationB: b3Vec3< The translation of shape B, in A’s frame
maxFraction: f32< The fraction of the translation to consider, typically 1
canEncroach: bool< Allows shapes with a radius to move slightly closer if already touching