b3SimplexCache

Struct b3SimplexCache 

#[repr(C)]
pub struct b3SimplexCache { pub metric: f32, pub count: u16, pub indexA: [u8; 4], pub indexB: [u8; 4], }
Used to warm start the GJK simplex. If you call this function multiple times with nearby transforms this might improve performance. Otherwise you can zero initialize this. The distance cache must be initialized to zero on the first call. Users should generally just zero initialize this structure for each call.

Fields

metric: f32

Value use to compare length, area, volume of two simplexes.

count: u16

The number of stored simplex points

indexA: [u8; 4]

The cached simplex indices on shape A

indexB: [u8; 4]

The cached simplex indices on shape B