b3SphericalJointDef

Struct b3SphericalJointDef 

#[repr(C)]
pub struct b3SphericalJointDef {
Show 13 fields pub base: b3JointDef, pub enableSpring: bool, pub hertz: f32, pub dampingRatio: f32, pub targetRotation: b3Quat, pub enableConeLimit: bool, pub coneAngle: f32, pub enableTwistLimit: bool, pub lowerTwistAngle: f32, pub upperTwistAngle: f32, pub enableMotor: bool, pub maxMotorTorque: f32, pub motorVelocity: b3Vec3,
}
Spherical joint definition. A point on body B is fixed to a point on body A. Allows rotation about the shared point. @ingroup spherical_joint

Fields

base: b3JointDef

Base joint definition

enableSpring: bool

Enable a rotational spring that attempts to align the two joint frames.

hertz: f32

The spring stiffness Hertz, cycles per second. This may be clamped internally according to the time step to maintain stability. Non-negative number.

dampingRatio: f32

The spring damping ratio, non-dimensional. Non-negative number.

targetRotation: b3Quat

Target spring rotation, joint frame B relative to joint frame A.

enableConeLimit: bool

A flag to enable the cone limit. The cone is centered on the frameA z-axis.

coneAngle: f32

The angle for the cone limit in radians. Valid range is [0, pi]

enableTwistLimit: bool

A flag to enable the twist limit. The twist is centered on the frameB z-axis.

lowerTwistAngle: f32

The angle for the lower twist limit in radians. Minimum of -0.99*pi radians.

upperTwistAngle: f32

The angle for the upper twist limit in radians. Maximum of 0.99*pi radians.

enableMotor: bool

A flag to enable the joint motor

maxMotorTorque: f32

The maximum motor torque, typically in newton-meters. Non-negative number.

motorVelocity: b3Vec3

The desired motor angular velocity in radians per second.