#[repr(C)]pub struct b3SurfaceMaterial {
pub friction: f32,
pub restitution: f32,
pub rollingResistance: f32,
pub tangentVelocity: b3Vec3,
pub userMaterialId: u64,
pub customColor: u32,
}Expand description
Material properties supported per triangle on meshes and height fields @ingroup shape
Fields
friction: f32The Coulomb (dry) friction coefficient, usually in the range [0,1].
restitution: f32The coefficient of restitution (bounce) usually in the range [0,1]. https://en.wikipedia.org/wiki/Coefficient_of_restitution
rollingResistance: f32The rolling resistance usually in the range [0,1]. This is only used for spheres and capsules.
tangentVelocity: b3Vec3The tangent velocity for conveyor belts. This is local to the shape and will be projected onto the contact surface.
userMaterialId: u64User material identifier. This is passed with query results and to friction and restitution combining functions. It is not used internally.
customColor: u32Custom debug draw color. Ignored if 0. The low 24 bits are RGB. The high byte may carry a b3DebugMaterial preset, see b3MakeDebugColor. @see b3HexColor