#[repr(C)]pub struct b3Sweep {
pub localCenter: b3Vec3,
pub c1: b3Vec3,
pub c2: b3Vec3,
pub q1: b3Quat,
pub q2: b3Quat,
}Expand description
This describes the motion of a body/shape for TOI computation. Shapes are defined with respect to the body origin, which may not coincide with the center of mass. However, to support dynamics we must interpolate the center of mass position.
Fields
localCenter: b3Vec3< Local center of mass position
c1: b3Vec3< Starting center of mass world position
c2: b3Vec3< Ending center of mass world position
q1: b3Quat< Starting world rotation
q2: b3Quat< Ending world rotation