#[repr(C)]pub struct b3TOIOutput {
pub state: b3TOIState,
pub point: b3Vec3,
pub normal: b3Vec3,
pub fraction: f32,
pub distance: f32,
pub distanceIterations: c_int,
pub pushBackIterations: c_int,
pub rootIterations: c_int,
pub usedFallback: bool,
}Expand description
Time of impact output
Fields
state: b3TOIStateThe type of result
point: b3Vec3The hit point
normal: b3Vec3The hit normal
fraction: f32The sweep time of the collision
distance: f32The final distance
distanceIterations: c_intNumber of outer iterations
pushBackIterations: c_intTotal number of push back iterations
rootIterations: c_intTotal number of root iterations
usedFallback: boolIndicates that the time of impact detected initial overlap and used a fallback sphere as a last ditch effort to prevent tunneling.