b3WorldDef

Struct b3WorldDef 

#[repr(C)]
pub struct b3WorldDef {
Show 21 fields pub gravity: b3Vec3, pub restitutionThreshold: f32, pub hitEventThreshold: f32, pub contactHertz: f32, pub contactDampingRatio: f32, pub contactSpeed: f32, pub maximumLinearSpeed: f32, pub frictionCallback: b3FrictionCallback, pub restitutionCallback: b3RestitutionCallback, pub enableSleep: bool, pub enableContinuous: bool, pub workerCount: u32, pub enqueueTask: b3EnqueueTaskCallback, pub finishTask: b3FinishTaskCallback, pub userTaskContext: *mut c_void, pub userData: *mut c_void, pub createDebugShape: b3CreateDebugShapeCallback, pub destroyDebugShape: b3DestroyDebugShapeCallback, pub userDebugShapeContext: *mut c_void, pub capacity: b3Capacity, pub internalValue: c_int,
}
World definition used to create a simulation world. Must be initialized using b3DefaultWorldDef. @ingroup world

Fields

gravity: b3Vec3

Gravity vector. Box3D has no up-vector defined.

restitutionThreshold: f32

Restitution speed threshold, usually in m/s. Collisions above this speed have restitution applied (will bounce).

hitEventThreshold: f32

Hit event speed threshold, usually in m/s. Collisions above this speed can generate hit events if the shape also enables hit events.

contactHertz: f32

Contact stiffness. Cycles per second. Increasing this increases the speed of overlap recovery, but can introduce jitter.

contactDampingRatio: f32

Contact bounciness. Non-dimensional. You can speed up overlap recovery by decreasing this with the trade-off that overlap resolution becomes more energetic.

contactSpeed: f32

This parameter controls how fast overlap is resolved and usually has units of meters per second. This only puts a cap on the resolution speed. The resolution speed is increased by increasing the hertz and/or decreasing the damping ratio.

maximumLinearSpeed: f32

Maximum linear speed. Usually meters per second.

frictionCallback: b3FrictionCallback

Optional mixing callback for friction. The default uses sqrt(frictionA * frictionB).

restitutionCallback: b3RestitutionCallback

Optional mixing callback for restitution. The default uses max(restitutionA, restitutionB).

enableSleep: bool

Can bodies go to sleep to improve performance

enableContinuous: bool

Enable continuous collision

workerCount: u32

Number of workers to use with the provided task system. Box3D performs best when using only performance cores and accessing a single L2 cache. Efficiency cores and hyper-threading provide little benefit and may even harm performance. This is clamped to the range [1, B3_MAX_WORKERS]. Using a value above 1 will turn on multithreading. If task callbacks are provided then Box3D will use the user provided task system. Otherwise Box3D will create threads and use an internal scheduler.

enqueueTask: b3EnqueueTaskCallback

function to spawn task

finishTask: b3FinishTaskCallback

function to finish a task

userTaskContext: *mut c_void

User context that is provided to enqueueTask and finishTask

userData: *mut c_void

User data associated with a world

createDebugShape: b3CreateDebugShapeCallback

Used to create debug draw shapes. This is called when a shape is first drawn using b3DebugDraw.

destroyDebugShape: b3DestroyDebugShapeCallback

Used to destroy debug draw shapes. This is called when a shape is modified or destroyed.

userDebugShapeContext: *mut c_void

This is passed to the debug shape callbacks to provide a user context.

capacity: b3Capacity

Optional initial capacities

internalValue: c_int

Used internally to detect a valid definition. DO NOT SET.