b3CreateDebugShapeCallback

Type Alias b3CreateDebugShapeCallback 

pub type b3CreateDebugShapeCallback = Option<unsafe extern "C" fn(debugShape: *const b3DebugShape, userContext: *mut c_void) -> *mut c_void>;
The user needs to be able to create debug draw shapes for multi-pass rendering to work efficiently. These user shapes are created and destroyed via callback so they can be bound to shape lifetime and scaling updates. @ingroup debug_draw

Aliased Type

pub enum b3CreateDebugShapeCallback {
    None,
    Some(unsafe extern "C" fn(*const b3DebugShape, *mut c_void) -> *mut c_void),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*const b3DebugShape, *mut c_void) -> *mut c_void)

Some value of type T.