b3EnqueueTaskCallback

Type Alias b3EnqueueTaskCallback 

pub type b3EnqueueTaskCallback = Option<unsafe extern "C" fn(task: b3TaskCallback, taskContext: *mut c_void, userContext: *mut c_void, taskName: *const c_char) -> *mut c_void>;
These functions can be provided to Box3D to invoke a task system. Returns a pointer to the user’s task object. May be nullptr. A nullptr indicates to Box3D that the work was executed serially within the callback and there is no need to call b3FinishTaskCallback. Otherwise the returned value must be non-null will be passed to b3FinishTaskCallback as the userTask. @param task the Box3D task to be called by the scheduler @param taskContext the Box3D context object that the scheduler must pass to the task @param userContext the scheduler context object that is opaque to Box3D @param taskName the Box3D task name that the scheduler can use for diagnostics @ingroup world

Aliased Type

pub enum b3EnqueueTaskCallback {
    None,
    Some(unsafe extern "C" fn(Option<unsafe extern "C" fn(*mut c_void)>, *mut c_void, *mut c_void, *const i8) -> *mut c_void),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(Option<unsafe extern "C" fn(*mut c_void)>, *mut c_void, *mut c_void, *const i8) -> *mut c_void)

Some value of type T.