b3JointType

Type Alias b3JointType 

pub type b3JointType = c_int;
Joint type enumeration. This is useful because all joint types use b3JointId and sometimes you want to get the type of a joint. @ingroup joint