pub type b3PreSolveFcn = Option<unsafe extern "C" fn(shapeIdA: b3ShapeId, shapeIdB: b3ShapeId, point: b3Pos, normal: b3Vec3, context: *mut c_void) -> bool>;Expand description
Prototype for a pre-solve callback. This is called after a contact is updated. This allows you to inspect a collision before it goes to the solver. Notes:
- this function must be thread-safe
- this is only called if the shape has enabled pre-solve events
- this may be called for awake dynamic bodies and sensors
- this is not called for sensors Return false if you want to disable the contact this step This has limited information because it is used during CCD which does not have the full contact manifold. @warning Do not attempt to modify the world inside this callback @ingroup world
Aliased Type
pub enum b3PreSolveFcn {
None,
Some(unsafe extern "C" fn(b3ShapeId, b3ShapeId, b3Vec3, b3Vec3, *mut c_void) -> bool),
}