pub type b3TaskCallback = Option<unsafe extern "C" fn(taskContext: *mut c_void)>;Expand description
Task interface This is the prototype for a Box3D task. Your task system is expected to run this callback on a worker thread, exactly once per enqueue, passing back the same taskContext pointer supplied to b3EnqueueTaskCallback. @ingroup world
Aliased Type
pub enum b3TaskCallback {
None,
Some(unsafe extern "C" fn(*mut c_void)),
}