b3TreeQueryClosestCallbackFcn

Type Alias b3TreeQueryClosestCallbackFcn 

pub type b3TreeQueryClosestCallbackFcn = Option<unsafe extern "C" fn(distanceSqrMin: f32, proxyId: c_int, userData: u64, context: *mut c_void) -> f32>;
This function receives the minimum distance squared so far and proxy to check in the closest query. @return minimum distance squared to user objects in the proxy

Aliased Type

pub enum b3TreeQueryClosestCallbackFcn {
    None,
    Some(unsafe extern "C" fn(f32, i32, u64, *mut c_void) -> f32),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(f32, i32, u64, *mut c_void) -> f32)

Some value of type T.