b3Body_AllowFastRotation

Function b3Body_AllowFastRotation 

pub unsafe extern "C" fn b3Body_AllowFastRotation(
    bodyId: b3BodyId,
    flag: bool,
)
Allow this body to rotate fast. Useful for axially symmetric bodies, such as vehicle wheels. Normally rotation speed is clamped to improve CCD. However, this clamping is unnecessary for bodies that only rotate fast around an axis of symmetry.