pub unsafe extern "C" fn b3Body_ApplyAngularImpulse(
bodyId: b3BodyId,
impulse: b3Vec3,
wake: bool,
)Expand description
Apply an angular impulse in world space. The impulse is ignored if the body is not awake. This optionally wakes the body. @param bodyId The body id @param impulse the world angular impulse vector, usually in units of kgmm/s @param wake also wake up the body @warning This should be used for one-shot impulses. If you need a steady torque, use a torque instead, which will work better with the sub-stepping solver.