pub unsafe extern "C" fn b3Body_SetMassData(
bodyId: b3BodyId,
massData: b3MassData,
)Expand description
Override the body’s mass properties. Normally this is computed automatically using the shape geometry and density. This information is lost if a shape is added or removed or if the body type changes.