pub unsafe extern "C" fn b3ConvertCompoundToBytes(
compound: *mut b3CompoundData,
) -> *mut u8Expand description
Cast the provided compound data to bytes, setting the internal pointers to null. Use this before serializing the compound bytes.
pub unsafe extern "C" fn b3ConvertCompoundToBytes(
compound: *mut b3CompoundData,
) -> *mut u8Cast the provided compound data to bytes, setting the internal pointers to null. Use this before serializing the compound bytes.