pub unsafe extern "C" fn b3CreateBakedCompoundShape(
bodyId: b3BodyId,
def: *mut b3ShapeDef,
compound: *const b3CompoundData,
) -> b3ShapeIdExpand description
Baked compound shapes are only allowed on static bodies. Note: runtime compounds are achieved by adding multiple shapes to a body. Runtime compounds can be dynamic and/or kinematic.