pub unsafe extern "C" fn b3CreateTransformedHullShape(
bodyId: b3BodyId,
def: *const b3ShapeDef,
hull: *const b3HullData,
transform: b3Transform,
scale: b3Vec3,
) -> b3ShapeIdExpand description
Create a convex hull shape and attach it to a body. The hull is cloned then transformed with scale applied first. Use this for non-uniform or mirrored scale or a baked local transform. The baked result is shared through the world hull database. The shape definition and geometry are fully cloned. Contacts are not created until the next time step. @return the shape id for accessing the shape