pub unsafe extern "C" fn b3QueryHeightField(
heightField: *const b3HeightFieldData,
bounds: b3AABB,
fcn: b3MeshQueryFcn,
context: *mut c_void,
)Expand description
Query a height field for triangles overlapping a bounding box in local space. May have false positives. Useful for debug draw. @param heightField the height field to query @param bounds the bounding box in local space @param fcn a user function to collect triangles @param context the context sent to the user function.