b3ScaleBox

Function b3ScaleBox 

pub unsafe extern "C" fn b3ScaleBox(
    halfWidths: *mut b3Vec3,
    transform: *mut b3Transform,
    postScale: b3Vec3,
    minHalfWidth: f32,
)
This takes a box with a transform and post scale and converts it into a box with the post scale resolved with new half-widths and transform. This accepts non-uniform and negative scale. This is approximate if there is shear. @param halfWidths [in/out] the box half widths @param transform [in/out] the box transform with rotation and translation @param postScale the post scale being applied to the box after the transform @param minHalfWidth the minimum half width after scale is applied