pub unsafe extern "C" fn b3Shape_GetSensorCapacity(
shapeId: b3ShapeId,
) -> c_intExpand description
Get the maximum capacity required for retrieving all the overlapped shapes on a sensor shape. This returns 0 if the provided shape is not a sensor. @param shapeId the id of a sensor shape @returns the required capacity to get all the overlaps in b3Shape_GetSensorOverlaps