b3SolvePlanes

Function b3SolvePlanes 

pub unsafe extern "C" fn b3SolvePlanes(
    targetDelta: b3Vec3,
    planes: *mut b3CollisionPlane,
    count: c_int,
) -> b3PlaneSolverResult
Solves the position of a mover that satisfies the given collision planes. @param targetDelta the desired translation from the position used to generate the collision planes @param planes the collision planes @param count the number of collision planes