pub unsafe extern "C" fn b3World_EnableSleeping(
worldId: b3WorldId,
flag: bool,
)Expand description
Enable/disable sleep. If your application does not need sleeping, you can gain some performance by disabling sleep completely at the world level. @see b3WorldDef