b3World_OverlapShape

Function b3World_OverlapShape 

pub unsafe extern "C" fn b3World_OverlapShape(
    worldId: b3WorldId,
    origin: b3Pos,
    proxy: *const b3ShapeProxy,
    filter: b3QueryFilter,
    fcn: b3OverlapResultFcn,
    context: *mut c_void,
) -> b3TreeStats
Overlap test for all shapes that overlap the provided shape proxy. The proxy points are relative to the world origin, which lets the query stay precise far from the world origin.