b3World_SetRestitutionThreshold

Function b3World_SetRestitutionThreshold 

pub unsafe extern "C" fn b3World_SetRestitutionThreshold(
    worldId: b3WorldId,
    value: f32,
)
Adjust the restitution threshold. It is recommended not to make this value very small because it will prevent bodies from sleeping. Usually in meters per second. @see b3WorldDef