b3CompoundData

Struct b3CompoundData 

#[repr(C)]
pub struct b3CompoundData {
Show 16 fields pub version: u64, pub byteCount: c_int, pub nodeOffset: c_int, pub tree: b3DynamicTree, pub materialOffset: c_int, pub materialCount: c_int, pub capsuleOffset: c_int, pub capsuleCount: c_int, pub hullOffset: c_int, pub hullCount: c_int, pub sharedHullCount: c_int, pub meshOffset: c_int, pub meshCount: c_int, pub sharedMeshCount: c_int, pub sphereOffset: c_int, pub sphereCount: c_int,
}
The runtime data for a compound shape. This is a potentially large yet highly optimized data structure. It can contain thousands of child shapes, yet at runtime it populates into the world as a single shape in the runtime broad-phase. This data structure has data living off the end and must be accessed using offsets. Accessors are provided for user relevant data.

Fields

version: u64

The compound version is always first.

byteCount: c_int

The total number of bytes for this compound.

nodeOffset: c_int

Offset of the tree node array in bytes from the struct address.

tree: b3DynamicTree

Immutable dynamic tree. The tree node pointer must be fixed up using the node offset

materialOffset: c_int

Offset of the material array in bytes from the struct address.

materialCount: c_int

The number of materials.

capsuleOffset: c_int

Offset of the capsule array in bytes from the struct address.

capsuleCount: c_int

The number of capsules.

hullOffset: c_int

Offset of the hull instance array in bytes from the struct address.

hullCount: c_int

The number of hull instances.

sharedHullCount: c_int

The number of unique hulls. Diagnostic.

meshOffset: c_int

Offset of the mesh instance array in bytes from the struct address.

meshCount: c_int

The number of mesh instances.

sharedMeshCount: c_int

The number of unique meshes. Diagnostic.

sphereOffset: c_int

Offset of the sphere array in bytes from the struct address.

sphereCount: c_int

The number of spheres.