#[repr(C)]pub struct b3DistanceInput {
pub proxyA: b3ShapeProxy,
pub proxyB: b3ShapeProxy,
pub transform: b3Transform,
pub useRadii: bool,
}Expand description
Input for b3ShapeDistance
Fields
proxyA: b3ShapeProxyThe proxy for shape A
proxyB: b3ShapeProxyThe proxy for shape B
transform: b3TransformTransform of shape B in shape A’s frame, the relative pose B in A (b3InvMulWorldTransforms( worldA, worldB )). The query is origin independent and runs in frame A.
useRadii: boolShould the proxy radius be considered?