#[repr(C)]pub struct b3HeightFieldData {Show 15 fields
pub version: u64,
pub byteCount: c_int,
pub hash: u32,
pub aabb: b3AABB,
pub minHeight: f32,
pub maxHeight: f32,
pub heightScale: f32,
pub scale: b3Vec3,
pub columnCount: c_int,
pub rowCount: c_int,
pub heightsOffset: c_int,
pub materialOffset: c_int,
pub flagsOffset: c_int,
pub clockwise: bool,
pub padding: [u8; 3],
}Expand description
A height field with compressed storage. @note This data structure has data hanging off the end and cannot be directly copied.
Fields
version: u64Version must be first and match B3_HEIGHT_FIELD_VERSION
byteCount: c_intThe total number of bytes for this height field.
hash: u32Hash of this height field (this field is zero when the hash is computed).
aabb: b3AABBThe local axis-aligned bounding box.
minHeight: f32The minimum y value.
maxHeight: f32The maximum y value
heightScale: f32The quantization scale.
scale: b3Vec3The overall scale.
columnCount: c_intThe number of grid columns along the local x-axis.
rowCount: c_intThe number of grid rows along the local z-axis.
heightsOffset: c_intOffset of the compressed height array in bytes from the struct address. uint16_t, one per grid point.
materialOffset: c_intOffset of the material index array in bytes from the struct address. uint8_t, one per cell.
flagsOffset: c_intOffset of the flag array in bytes from the struct address. uint8_t, one per triangle.
clockwise: boolTriangle winding.
padding: [u8; 3]Explicit padding. Identity is a content hash over raw bytes, so there must be no unnamed padding for struct copies to scramble.