b3HeightFieldDef

Struct b3HeightFieldDef 

#[repr(C)]
pub struct b3HeightFieldDef { pub heights: *mut f32, pub materialIndices: *mut u8, pub scale: b3Vec3, pub countX: c_int, pub countZ: c_int, pub globalMinimumHeight: f32, pub globalMaximumHeight: f32, pub clockwiseWinding: bool, }
Data used to create a height field

Fields

heights: *mut f32

Grid point heights count = countX * countZ

materialIndices: *mut u8

Grid cell material A value of 0xFF is reserved for holes count = (countX - 1) * (countZ - 1)

scale: b3Vec3

The height field scale. All components must be positive values.

countX: c_int

The number of grid lines along the x-axis.

countZ: c_int

The number of grid lines along the z-axis.

globalMinimumHeight: f32

Global minimum and maximum heights used for quantization. This is important if you want height fields to be placed next to each other and line up exactly. In that case, both height fields should use the same minimum and maximum heights. All height values are clamped to this range. These values are in unscaled space.

globalMaximumHeight: f32

The maximum.

clockwiseWinding: bool

Use clock-wise winding. This effectively inverts the height-field along the y-axis.