#[repr(C)]pub struct b3HullData {Show 18 fields
pub version: u64,
pub byteCount: c_int,
pub hash: u32,
pub aabb: b3AABB,
pub surfaceArea: f32,
pub volume: f32,
pub innerRadius: f32,
pub center: b3Vec3,
pub centralInertia: b3Matrix3,
pub vertexCount: c_int,
pub vertexOffset: c_int,
pub pointOffset: c_int,
pub edgeCount: c_int,
pub edgeOffset: c_int,
pub faceCount: c_int,
pub faceOffset: c_int,
pub planeOffset: c_int,
pub padding: c_int,
}Expand description
A convex hull. @note This data structure has data hanging off the end and cannot be directly copied.
Fields
version: u64Version must be first and match B3_HULL_VERSION
byteCount: c_intThe total number of bytes for this hull.
hash: u32Hash of this hull (this field is zero when the hash is computed).
aabb: b3AABBAxis-aligned box in local space.
surfaceArea: f32Surface area, typically in squared meters.
volume: f32Volume, typically in m^3.
innerRadius: f32The radius of the largest sphere at the center.
center: b3Vec3The local centroid
centralInertia: b3Matrix3The inertia tensor about the centroid.
vertexCount: c_intThe vertex count.
vertexOffset: c_intOffset of the vertex array in bytes from the struct address.
pointOffset: c_intOffset of the point array in bytes from the struct address.
edgeCount: c_intThis is the half-edge count (double the edge count)
edgeOffset: c_intOffset of the edge array in bytes from the struct address.
faceCount: c_intThe face count. Hulls faces are convex polygons.
faceOffset: c_intOffset of the face array in bytes from the struct address.
planeOffset: c_intOffset of the face plane array in bytes from the struct address.
padding: c_intExplicit padding. Hull identity is a content hash and memcmp over raw bytes, so there must be no unnamed padding for struct copies to scramble.