#[repr(C)]pub struct b3HullVertex {
pub edge: u8,
}Expand description
A hull vertex. Identified by a half-edge with this vertex as its tail.
Fields
edge: u8A half-edge that has this vertex as the origin Can be used along with edge twins and winding order to traverse all the edges connected to this vertex.