#[repr(C)]pub struct b3Manifold {
pub points: [b3ManifoldPoint; 4],
pub normal: b3Vec3,
pub twistImpulse: f32,
pub frictionImpulse: b3Vec3,
pub rollingImpulse: b3Vec3,
pub pointCount: c_int,
}Expand description
A contact manifold describes the contact points between colliding shapes. @note Box3D uses speculative collision so some contact points may be separated.
Fields
points: [b3ManifoldPoint; 4]The manifold points. There may be 1 to 4 valid points.
normal: b3Vec3The unit normal vector in world space, points from shape A to shape B
twistImpulse: f32Central friction angular impulse (applied about the normal)
frictionImpulse: b3Vec3Central friction linear impulse
rollingImpulse: b3Vec3Rolling resistance angular impulse
pointCount: c_intThe number of contact points, will be 0 to 4