#[repr(C)]pub struct b3MeshData {Show 16 fields
pub version: u64,
pub byteCount: c_int,
pub hash: u32,
pub bounds: b3AABB,
pub surfaceArea: f32,
pub treeHeight: c_int,
pub degenerateCount: c_int,
pub nodeOffset: c_int,
pub nodeCount: c_int,
pub vertexOffset: c_int,
pub vertexCount: c_int,
pub triangleOffset: c_int,
pub triangleCount: c_int,
pub materialOffset: c_int,
pub materialCount: c_int,
pub flagsOffset: c_int,
}Expand description
This is a sorted triangle collision bounding volume hierarchy. @note This struct has data hanging off the end and cannot be directly copied.
Fields
version: u64Version must be first.
byteCount: c_intThe total number of bytes for this mesh.
hash: u32Hash of this mesh (this field is zero when the hash is computed)
bounds: b3AABBLocal axis-aligned box.
surfaceArea: f32Combined surface area of all triangles. Single-sided.
treeHeight: c_intThe height of the bounding volume hierarchy.
degenerateCount: c_intThe number of degenerate triangles. Diagnostic.
nodeOffset: c_intOffset of the node array in bytes from the struct address.
nodeCount: c_intThe number of BVH nodes.
vertexOffset: c_intOffset of the vertex array in bytes from the struct address.
vertexCount: c_intThe number of vertices.
triangleOffset: c_intOffset of the triangle array in bytes from the struct address.
triangleCount: c_intThe number of triangles.
materialOffset: c_intOffset of the material array in bytes from the struct address.
materialCount: c_intThe number of materials.
flagsOffset: c_intOffset of the triangle flag array in bytes from the struct address.