#[repr(C)]pub struct b3MeshDef {
pub vertices: *mut b3Vec3,
pub indices: *mut i32,
pub materialIndices: *mut u8,
pub weldTolerance: f32,
pub vertexCount: c_int,
pub triangleCount: c_int,
pub weldVertices: bool,
pub useMedianSplit: bool,
pub identifyEdges: bool,
}Expand description
This is used to create a re-usable collision mesh
Fields
vertices: *mut b3Vec3Triangle vertices
indices: *mut i32Triangle vertex indices. 3 for each triangle.
materialIndices: *mut u8Triangle material index. 1 per triangle. Indexes into b3ShapeDef::materials. This allows different run-time material data to be associated with different instances of this mesh.
weldTolerance: f32Tolerance for vertex welding in length units.
vertexCount: c_intThe vertex count. Must be 3 or more.
triangleCount: c_intThe triangle count. Must be 1 or more.
weldVertices: boolOptionally weld nearby vertices.
useMedianSplit: boolUse the median split instead of SAH to speed up mesh creation. Good for meshes that are structured like a grid.
identifyEdges: boolCompute triangle adjacency information using shared edges