#[repr(C)]pub struct b3RevoluteJointDef {
pub base: b3JointDef,
pub targetAngle: f32,
pub enableSpring: bool,
pub hertz: f32,
pub dampingRatio: f32,
pub enableLimit: bool,
pub lowerAngle: f32,
pub upperAngle: f32,
pub enableMotor: bool,
pub maxMotorTorque: f32,
pub motorSpeed: f32,
}Expand description
Revolute joint definition. A point on body B is fixed to a point on body A. Allows relative rotation about the z-axis. @ingroup revolute_joint
Fields
base: b3JointDefBase joint definition.
targetAngle: f32The bodyB angle minus bodyA angle in the reference state (radians). This defines the zero angle for the joint limit.
enableSpring: boolEnable a rotational spring on the revolute hinge axis.
hertz: f32The spring stiffness Hertz, cycles per second.
dampingRatio: f32The spring damping ratio, non-dimensional.
enableLimit: boolA flag to enable joint limits.
lowerAngle: f32The lower angle for the joint limit in radians. Minimum of -0.99*pi radians.
upperAngle: f32The upper angle for the joint limit in radians. Maximum of 0.99*pi radians.
enableMotor: boolA flag to enable the joint motor.
maxMotorTorque: f32The maximum motor torque, typically in newton-meters.
motorSpeed: f32The desired motor speed in radians per second.